a vector containing the numerical dosage of each dose level
npts
a vector containing the number of patients treated at each dose level
nDLT
a vector containing the number of patients who experienced dose-limiting
toxicity at each dose level
elimdose
the dosage at the dose level which is excluded due to excessive toxicity
Details
hybrid.MTD.selection() selects the MTD based on isotonic estimates of toxicity
probabilities. The isotonic estimates are obtained by the pooled-adjacent-violators
algorithm (PAVA) (Barlow, 1972 <doi: 10.1080/01621459.1972.10481216>).